@@ -113,6 +113,10 @@ void testRandGauss(std::vector<double> const& reference, bool& result) {
     #pragma GCC diagnostic ignored "-Wshadow"
   #endif
 #endif 
+#if defined  __INTEL_COMPILER
+  #pragma warning push
+  #pragma warning disable 1599
+#endif
 #ifdef __clang__
   #pragma clang diagnostic push
   #pragma clang diagnostic ignored "-Wshadow"
@@ -225,9 +229,9 @@ int main() {
     CLHEP::MixMaxRng engine1;
     CLHEP::MixMaxRng engine2;
     CLHEP::MixMaxRng engine3;
-    if(std::fabs(engine1.flat() - 0.925809) > epsilon ||
-       std::fabs(engine2.flat() - 0.918272) > epsilon ||
-       std::fabs(engine3.flat() - 0.0354222) > epsilon) {
+    if(std::fabs(engine1.flat() - 0.13049) > epsilon ||
+       std::fabs(engine2.flat() - 0.519572) > epsilon ||
+       std::fabs(engine3.flat() - 0.840834) > epsilon) {
       output << "Error, default seeds changed for MixMaxRng random engine.\n";
       return 1;
     }
@@ -352,6 +356,9 @@ int main() {
     #pragma GCC diagnostic pop
   #endif
 #endif 
+#if defined  __INTEL_COMPILER
+  #pragma warning pop
+#endif
 #ifdef __clang__
   #pragma clang diagnostic pop
 #endif
